==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/EnumToSimpleMap.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author Cody Short
 */

/**
 * API Status: **Private**
 * @module nmodule/converters/rc/EnumToSimpleMap
 */

define(['baja!', 'underscore'], function (baja, _) {
  "use strict";

  /**
   * A bajaux implementation of an EnumToSimpleMap converter.
   * @alias module:nmodule/converters/rc/EnumToSimpleMap
   * @extends baja.Simple
   */
  var EnumToSimpleMap = /*#__PURE__*/function (_baja$Simple) {
    /**
     * The representation of values in the map.
     * @typedef {Object} module:converters/rc/EnumToSimpleMap/Item
     * @property {number} min
     * @property {number} max
     * @property {value} baja.Simple
     */

    /**
     * A Component that represents a Niagara 'converters:EnumToSimpleMap' Type.
     *
     * @name EnumToSimpleMap
     * @extends baja.Simple
     * @param {Array<module:converters/rc/EnumToSimpleMap/Item>} items
     * @param {baja.Simple} def
     */
    function EnumToSimpleMap(items, def) {
      var _this;
      _classCallCheck(this, EnumToSimpleMap);
      _this = _callSuper(this, EnumToSimpleMap, arguments);
      _this.$items = items;
      _this.$def = def;
      return _this;
    }

    /**
     * Make an EnumToSimpleMap
     *
     * @param {Object|string} obj Object Literal for the method's arguments.
     *   or the string encoding to be loaded in. 
     * @param {String} [obj.str] the String encoding.
     * @param {Array<module:converters/rc/EnumToSimpleMap/Item>} [obj.items] the items that are mapped
     * @param {baja.Simple} [obj.default] the default value of the map
     * @return {EnumToSimpleMap}
     */
    _inherits(EnumToSimpleMap, _baja$Simple);
    return _createClass(EnumToSimpleMap, [{
      key: "make",
      value: function make(obj) {
        if (obj && (obj.def || obj.items)) {
          var _items = obj.items || [],
            def = obj.def || null;
          return new EnumToSimpleMap(_items, def);
        }
        obj = baja.objectify(obj, "str");
        if (!obj || !obj.str) {
          throw new Error("EnumToSimpleMap.make passed invalid value");
        }
        if (obj.str === "null") {
          return EnumToSimpleMap.DEFAULT;
        }

        // Get the prototype instance (used to decode everything else)
        var protoRes = /^([^ ]+) (.*)/.exec(obj.str);
        if (protoRes.length <= 1) {
          throw new Error("Cannot decode EnumToSimpleMap" + obj.str);
        }

        // Decode the prototype simple we're going to decode from
        var proto = baja.$(protoRes[1]);

        // Separate out the value pairs
        var valPairRegEx = /([^;]*)=(([^;]|;;)*)/g;
        var valPairRes,
          defValue = null,
          value,
          items = [];
        valPairRes = valPairRegEx.exec(protoRes[2]);
        while (valPairRes) {
          // Decode the value from the String
          var encodedValue = valPairRes[2].replace(/;;/g, ";");
          value = proto.decodeFromString(encodedValue);
          if (valPairRes[1] === "default") {
            defValue = value;
          } else {
            //parse comma-delimited ordinals
            var ordinals = valPairRes[1].split(',');
            ordinals.forEach(function (ordinalStr) {
              items.push({
                ordinal: parseInt(ordinalStr, 10),
                value: value
              });
            });
          }
          valPairRes = valPairRegEx.exec(protoRes[2]);
        }
        return new EnumToSimpleMap(items, defValue);
      }
    }, {
      key: "decodeFromString",
      value:
      /**
       * Decode a EnumToSimpleMap
       *
       * @param {String} str
       * @return {EnumToSimpleMap}
       */
      function decodeFromString(str) {
        return EnumToSimpleMap.make(str);
      }
    }, {
      key: "decodeAsync",
      value:
      /**
       *
       * @param {string} str
       * @param {baja.comm.Batch} [batch]
       * @return {Promise}
       */
      function decodeAsync(str, batch) {
        if (str === "null") {
          return Promise.resolve(EnumToSimpleMap.DEFAULT);
        }

        // Get the prototype instance (used to decode everything else)
        var protoRes = /^([^ ]+) (.*)/.exec(str);
        if (protoRes.length <= 1) {
          throw new Error("Cannot decode EnumToSimpleMap" + str);
        }

        // Decode the prototype simple we're going to decode from
        var typeToImport = protoRes[1];
        return Promise.resolve(baja.importTypes({
          typeSpecs: [typeToImport],
          batch: batch
        })).then(function () {
          return EnumToSimpleMap.make(str);
        });
      }
    }, {
      key: "encodeToString",
      value:
      /**
       * Encode the EnumToSimpleMap to a String
       *
       * @return {String}
       */
      function encodeToString() {
        var str = "";
        if (this.$items.length === 0 && this.$def === null) {
          return "null";
        }
        str = "".concat(this.getValueType().toString(), " ");
        this.$items.forEach(function (item) {
          var encodedString = item.value.encodeToString(),
            value = "".concat(item.ordinal, "=").concat(encodedString.replace(/;/g, ";;"), ";");
          str = str.concat(value);
        });
        if (this.$items.length > 0) {
          str = str.substring(0, str.length - 1);
        }
        if (this.$def !== null) {
          if (this.$items.length > 0) {
            str = str.concat(";");
          }
          var encodedString = this.$def.encodeToString();
          str = str.concat("default=".concat(encodedString.replace(/;/g, ";;")));
        }
        return str;
      }
    }, {
      key: "isNull",
      value:
      /**
       * Determines whether the EnumToSimpleMap is null based upon items.
       * @returns {boolean}
       */
      function isNull() {
        return this.$items.length === 0;
      }

      /**
       * Gets the values from items
       * @returns {Array.<baja.Simple>}
       */
    }, {
      key: "getValues",
      value: function getValues() {
        return _.pluck(this.$items, 'value');
      }

      /**
       * Gets the ordinals from items
       * @returns {Array.<number>}
       */
    }, {
      key: "getOrdinals",
      value: function getOrdinals() {
        return _.pluck(this.$items, 'ordinal');
      }

      /**
       * Gets the default values
       * @returns {baja.Simple|null}
       */
    }, {
      key: "getDefault",
      value: function getDefault() {
        return this.$def;
      }

      /**
       * Determines the type of values in the map.
       * @returns {baja.Type|null}
       */
    }, {
      key: "getValueType",
      value: function getValueType() {
        if (this.$def) {
          return this.$def.getType();
        } else if (this.$items.length > 0) {
          return this.$items[0].value.getType();
        }
        return null;
      }

      /**
       * Equality test
       *
       * @param {Object} obj
       * @return {boolean}
       */
    }, {
      key: "equals",
      value: function equals(obj) {
        var it, objIt, i;
        if (baja.hasType(obj) && obj.getType().equals(this.getType()) && obj.$items.length === this.$items.length) {
          // Compare items
          for (i = 0; i < this.$items.length; ++i) {
            it = this.$items[i];
            objIt = obj.$items[i];
            if (it.ordinal !== objIt.ordinal || !it.value.equals(objIt.value)) {
              return false;
            }
          }

          // Compare default values
          if (this.$def === null) {
            return obj.$def === null;
          } else {
            if (obj.$def === null) {
              return false;
            } else {
              return obj.$def.equals(this.$def);
            }
          }
        }
        return false;
      }
    }, {
      key: "get",
      value:
      /**
       * Get a simple by its ordinal value or return the default if no mapping.
       *
       * @param {number} ordinal
       * @return {baja.Simple} the value (or null if no default is specified).
       */
      function get(ordinal) {
        var it = this.$items,
          i;
        for (i = 0; i < it.length; ++i) {
          if (it[i].ordinal === ordinal) {
            return it[i].value;
          }
        }
        return this.$def;
      }
    }], [{
      key: "make",
      value:
      /**
       * Make an EnumToSimpleMap
       *
       * @param {Object|string} obj Object Literal for the method's arguments.
       *   or the string encoding to be loaded in.
       * @param {String} obj.str the String encoding.
       * @param {Array<module:converters/rc/EnumToSimpleMap/Item>} [obj.items] the items that are mapped
       * @param {baja.Simple} [obj.default] the default value of the map
       * @return {EnumToSimpleMap}
       */
      function make(obj) {
        return EnumToSimpleMap.DEFAULT.make(obj);
      }
    }]);
  }(baja.Simple);
  /**
   * Default NumericToSimpleMap instance
   */
  EnumToSimpleMap.DEFAULT = new EnumToSimpleMap([], null);
  return EnumToSimpleMap;
});

==> Tridium_EMEA_N4_Supervisor-4.14.2.12.zip: rc/EnumToSimpleMap.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author Cody Short
 */

/**
 * API Status: **Private**
 * @module nmodule/converters/rc/EnumToSimpleMap
 */

define(['baja!', 'Promise', 'underscore'], function (baja, Promise, _) {
  "use strict";

  /**
   * A bajaux implementation of an EnumToSimpleMap converter.
   * @alias module:nmodule/converters/rc/EnumToSimpleMap
   * @extends baja.Simple
   */
  var EnumToSimpleMap = /*#__PURE__*/function (_baja$Simple) {
    /**
     * The representation of values in the map.
     * @typedef {Object} module:converters/rc/EnumToSimpleMap/Item
     * @property {number} min
     * @property {number} max
     * @property {value} baja.Simple
     */

    /**
     * A Component that represents a Niagara 'converters:EnumToSimpleMap' Type.
     *
     * @name EnumToSimpleMap
     * @extends baja.Simple
     * @param {Array<module:converters/rc/EnumToSimpleMap/Item>} items
     * @param {baja.Simple} def
     */
    function EnumToSimpleMap(items, def) {
      var _this;
      _classCallCheck(this, EnumToSimpleMap);
      _this = _callSuper(this, EnumToSimpleMap, arguments);
      _this.$items = items;
      _this.$def = def;
      return _this;
    }

    /**
     * Make an EnumToSimpleMap
     *
     * @param {Object|string} obj Object Literal for the method's arguments.
     *   or the string encoding to be loaded in. 
     * @param {String} [obj.str] the String encoding.
     * @param {Array<module:converters/rc/EnumToSimpleMap/Item>} [obj.items] the items that are mapped
     * @param {baja.Simple} [obj.default] the default value of the map
     * @return {EnumToSimpleMap}
     */
    _inherits(EnumToSimpleMap, _baja$Simple);
    return _createClass(EnumToSimpleMap, [{
      key: "make",
      value: function make(obj) {
        if (obj && (obj.def || obj.items)) {
          var _items = obj.items || [],
            def = obj.def || null;
          return new EnumToSimpleMap(_items, def);
        }
        obj = baja.objectify(obj, "str");
        if (!obj || !obj.str) {
          throw new Error("EnumToSimpleMap.make passed invalid value");
        }
        if (obj.str === "null") {
          return EnumToSimpleMap.DEFAULT;
        }

        // Get the prototype instance (used to decode everything else)
        var protoRes = /^([^ ]+) (.*)/.exec(obj.str);
        if (protoRes.length <= 1) {
          throw new Error("Cannot decode EnumToSimpleMap" + obj.str);
        }

        // Decode the prototype simple we're going to decode from
        var proto = baja.$(protoRes[1]);

        // Separate out the value pairs
        var valPairRegEx = /([^;]*)=(([^;]|;;)*)/g;
        var valPairRes,
          defValue = null,
          value,
          items = [];
        valPairRes = valPairRegEx.exec(protoRes[2]);
        while (valPairRes) {
          // Decode the value from the String
          var encodedValue = valPairRes[2].replace(/;;/g, ";");
          value = proto.decodeFromString(encodedValue);
          if (valPairRes[1] === "default") {
            defValue = value;
          } else {
            //parse comma-delimited ordinals
            var ordinals = valPairRes[1].split(',');
            ordinals.forEach(function (ordinalStr) {
              items.push({
                ordinal: parseInt(ordinalStr, 10),
                value: value
              });
            });
          }
          valPairRes = valPairRegEx.exec(protoRes[2]);
        }
        return new EnumToSimpleMap(items, defValue);
      }

      /**
       * Decode a EnumToSimpleMap
       *
       * @param {String} str
       * @return {EnumToSimpleMap}
       */
    }, {
      key: "decodeFromString",
      value: function decodeFromString(str) {
        return EnumToSimpleMap.make(str);
      }

      /**
       *
       * @param {string} str
       * @param {baja.comm.Batch} [batch]
       * @return {Promise}
       */
    }, {
      key: "decodeAsync",
      value: function decodeAsync(str, batch) {
        if (str === "null") {
          return Promise.resolve(EnumToSimpleMap.DEFAULT);
        }

        // Get the prototype instance (used to decode everything else)
        var protoRes = /^([^ ]+) (.*)/.exec(str);
        if (protoRes.length <= 1) {
          throw new Error("Cannot decode EnumToSimpleMap" + str);
        }

        // Decode the prototype simple we're going to decode from
        var typeToImport = protoRes[1];
        return Promise.resolve(baja.importTypes({
          typeSpecs: [typeToImport],
          batch: batch
        })).then(function () {
          return EnumToSimpleMap.make(str);
        });
      }

      /**
       * Encode the EnumToSimpleMap to a String
       *
       * @return {String}
       */
    }, {
      key: "encodeToString",
      value: function encodeToString() {
        var str = "";
        if (this.$items.length === 0 && this.$def === null) {
          return "null";
        }
        str = "".concat(this.getValueType().toString(), " ");
        this.$items.forEach(function (item) {
          var encodedString = item.value.encodeToString(),
            value = "".concat(item.ordinal, "=").concat(encodedString.replace(/;/g, ";;"), ";");
          str = str.concat(value);
        });
        if (this.$items.length > 0) {
          str = str.substring(0, str.length - 1);
        }
        if (this.$def !== null) {
          if (this.$items.length > 0) {
            str = str.concat(";");
          }
          var encodedString = this.$def.encodeToString();
          str = str.concat("default=".concat(encodedString.replace(/;/g, ";;")));
        }
        return str;
      }

      /**
       * Determines whether the EnumToSimpleMap is null based upon items.
       * @returns {boolean}
       */
    }, {
      key: "isNull",
      value: function isNull() {
        return this.$items.length === 0;
      }

      /**
       * Gets the values from items
       * @returns {Array.<baja.Simple>}
       */
    }, {
      key: "getValues",
      value: function getValues() {
        return _.pluck(this.$items, 'value');
      }

      /**
       * Gets the ordinals from items
       * @returns {Array.<number>}
       */
    }, {
      key: "getOrdinals",
      value: function getOrdinals() {
        return _.pluck(this.$items, 'ordinal');
      }

      /**
       * Gets the default values
       * @returns {baja.Simple|null}
       */
    }, {
      key: "getDefault",
      value: function getDefault() {
        return this.$def;
      }

      /**
       * Determines the type of values in the map.
       * @returns {baja.Type|null}
       */
    }, {
      key: "getValueType",
      value: function getValueType() {
        if (this.$def) {
          return this.$def.getType();
        } else if (this.$items.length > 0) {
          return this.$items[0].value.getType();
        }
        return null;
      }

      /**
       * Equality test
       *
       * @param {Object} obj
       * @return {boolean}
       */
    }, {
      key: "equals",
      value: function equals(obj) {
        var it, objIt, i;
        if (baja.hasType(obj) && obj.getType().equals(this.getType()) && obj.$items.length === this.$items.length) {
          // Compare items
          for (i = 0; i < this.$items.length; ++i) {
            it = this.$items[i];
            objIt = obj.$items[i];
            if (it.ordinal !== objIt.ordinal || !it.value.equals(objIt.value)) {
              return false;
            }
          }

          // Compare default values
          if (this.$def === null) {
            return obj.$def === null;
          } else {
            if (obj.$def === null) {
              return false;
            } else {
              return obj.$def.equals(this.$def);
            }
          }
        }
        return false;
      }

      /**
       * Get a simple by its ordinal value or return the default if no mapping.
       *
       * @param {number} ordinal
       * @return {baja.Simple} the value (or null if no default is specified).
       */
    }, {
      key: "get",
      value: function get(ordinal) {
        var it = this.$items,
          i;
        for (i = 0; i < it.length; ++i) {
          if (it[i].ordinal === ordinal) {
            return it[i].value;
          }
        }
        return this.$def;
      }

      /**
       * Make an EnumToSimpleMap
       *
       * @param {Object|string} obj Object Literal for the method's arguments.
       *   or the string encoding to be loaded in.
       * @param {String} obj.str the String encoding.
       * @param {Array<module:converters/rc/EnumToSimpleMap/Item>} [obj.items] the items that are mapped
       * @param {baja.Simple} [obj.default] the default value of the map
       * @return {EnumToSimpleMap}
       */
    }], [{
      key: "make",
      value: function make(obj) {
        return EnumToSimpleMap.DEFAULT.make(obj);
      }
    }]);
  }(baja.Simple);
  /**
   * Default NumericToSimpleMap instance
   */
  EnumToSimpleMap.DEFAULT = new EnumToSimpleMap([], null);
  return EnumToSimpleMap;
});
